==============
Code reference
==============

.. toctree::
  :maxdepth: 2


module-level
============
.. autofunction:: ggf.fiber_distance_capillary

.. autofunction:: ggf.get_ggf

.. autofunction:: ggf.legendre2ggf

.. autofunction:: ggf.stress2ggf

.. autofunction:: ggf.stress2legendre


matlab_funcs
============
.. automodule:: ggf.matlab_funcs
   :members:
   :undoc-members:


sci_funcs
=========
.. automodule:: ggf.sci_funcs
   :members:
   :undoc-members:


stress
======

.. autofunction:: ggf.stress.get_stress


stress.boyde2009
----------------

stress.boyde2009.core
.....................

.. automodule:: ggf.stress.boyde2009.core
   :members:
   :undoc-members:


stress.boyde2009.globgeomfact
.............................

.. automodule:: ggf.stress.boyde2009.globgeomfact
   :members:
   :undoc-members:

